==> quantis-v10.10.08-src.zip: Quantis-v10.10.08/Libs-Apps/EasyQuantis/Utils.hpp <==
/*
 * This file is part of the EasyQuantis application
 *
 * Copyright (c) 2004-2010 id Quantique SA, Carouge/Geneva, Switzerland
 * All rights reserved.
 *
 * ----------------------------------------------------------------------------
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY.
 *
 * ----------------------------------------------------------------------------
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License version 2 as published by the Free Software 
 * Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 * ----------------------------------------------------------------------------
 *
 * For history of changes, see ChangeLog.txt
 */

#ifndef EASY_QUANTIS_UTILS_HPP
#define EASY_QUANTIS_UTILS_HPP

#include <boost/date_time/posix_time/posix_time.hpp>
#include <string>

#include "Quantis/Quantis.hpp"

namespace idQ
{
  namespace EasyQuantis
  {
    /**
     *
     */
    enum RandomDataType
    {
      RANDOM_DATA_TYPE_BINARY,
      RANDOM_DATA_TYPE_INTEGERS,
      RANDOM_DATA_TYPE_FLOATS
    };

    /**
     *
     */
    struct RandomDataGenerationInfo
    {
      QuantisDeviceType deviceType;
      unsigned int deviceNumber;
      RandomDataType dataType;
      unsigned long long count;
      std::string dataSeparator;
      bool scaleData;
      double min;
      double max;
    };


    /**
     *
     */
    namespace Utils
    {
      /**
       * Creates a string in the format "X of Y - T time left (Z bytes/sec)".
       */
      std::string BuildProgressInfoString(
          const boost::posix_time::ptime& timeStart,
          const RandomDataGenerationInfo& randomDataGenerationInfo,
          const unsigned long long& remainingSize,
          int& progressValue);

      /**
       * Convert the give size in bytes to a human readable string
       * @param size
       * @param addByteString
       */
      std::string FormatSize(unsigned long long size, bool addByteString = true);

      /**
       * Convert the give time in seconds to a human readable string
       * @param seconds
       */
      std::string FormatTime(unsigned long long seconds);
    }
  }
}

#endif

==> quantis-v12.09.12-src.zip: Quantis-v12.09.12/Libs-Apps/EasyQuantis/Utils.hpp <==
/*
 * This file is part of the EasyQuantis application
 *
 * Copyright (C) 2004-2012 ID Quantique SA, Carouge/Geneva, Switzerland
 * All rights reserved.
 *
 * ----------------------------------------------------------------------------
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY.
 *
 * ----------------------------------------------------------------------------
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License version 2 as published by the Free Software 
 * Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 * ----------------------------------------------------------------------------
 *
 * For history of changes, see ChangeLog.txt
 */

#ifndef EASY_QUANTIS_UTILS_HPP
#define EASY_QUANTIS_UTILS_HPP

#include <boost/date_time/posix_time/posix_time.hpp>
#include <string>

#include "Quantis/Quantis.hpp"

namespace idQ
{
  namespace EasyQuantis
  {
    /**
     *
     */
    enum RandomDataType
    {
      RANDOM_DATA_TYPE_BINARY,
      RANDOM_DATA_TYPE_INTEGERS,
      RANDOM_DATA_TYPE_FLOATS
    };

    /**
     *
     */
    struct RandomDataGenerationInfo
    {
      QuantisDeviceType deviceType;
      unsigned int deviceNumber;
      RandomDataType dataType;
      unsigned long long count;
      std::string dataSeparator;
      bool scaleData;
      double min;
      double max;
      bool extractorEnabled;
      int extractorMatrixSizeIn;
      int extractorMatrixSizeOut;
      std::string extractorMatrixFilename;
    };

    struct FileExtractionGenerationInfo
    {
      unsigned long long count;
      int extractorMatrixSizeIn;
      int extractorMatrixSizeOut;
      std::string extractorMatrixFilename;
      std::string inputFile;
      std::string outputFile;
    };    

    
    struct ElementaryMatrixExtractionGenerationInfo
    {
      QuantisDeviceType deviceType;
      unsigned int deviceNumber;
      unsigned long long count;
      int extractorMatrixSizeIn;
      int extractorMatrixSizeOut;
      int numberOfBytesToSkip;
      std::string outputElementaryMatrixFile;
    };     

    struct MatrixExtractionGenerationInfo
    {
      int extractorMatrixSizeIn;
      int extractorMatrixSizeOut;      
      std::vector<std::string> elementaryMatrixFiles;
      std::string outputMatrixFile;      
    };     
    
    /**
     *
     */
    namespace Utils
    {
      /**
       * Creates a string in the format "X of Y - T time left (Z bytes/sec)".
       */
      std::string BuildProgressInfoString(
          const boost::posix_time::ptime& timeStart,
          const RandomDataGenerationInfo& randomDataGenerationInfo,
          const unsigned long long& remainingSize,
          int& progressValue);

      /**
       * Convert the give size in bytes to a human readable string
       * @param size
       * @param addByteString
       */
      std::string FormatSize(unsigned long long size, bool addByteString = true);

      /**
       * Convert the give time in seconds to a human readable string
       * @param seconds
       */
      std::string FormatTime(unsigned long long seconds);
      
      
      std::string BuildProcessExtractionProgressInfoString(
          const boost::posix_time::ptime& timeStart,
          const FileExtractionGenerationInfo& fileExtractionGenerationInfo,
          const unsigned long long& remainingSize,
          int& progressValue);   
      
      std::string BuildProgressExtractionElementaryMatrixInfoString(
          const boost::posix_time::ptime& timeStart,
          const ElementaryMatrixExtractionGenerationInfo& elementaryMatrixExtractionGenerationInfo,
          const unsigned long long& remainingSize,
          int& progressValue);      
      
    }
  }
}

#endif
